@@ -329,7 +329,7 @@ def change_bulkstatus_to_string(df):
         df.loc[(df['BulkStatus'] == 0), 'BulkStatus'] = 'New'
         df.loc[(df['BulkStatus'] == 6), 'BulkStatus'] = 'OOO'
         df.loc[(df['BulkStatus'] == 12), 'BulkStatus'] = 'NN'
-        df.loc[~(df['BulkStatus'] in (2,0,6,12), 'BulkStatus'] = 'Other'
+        df.loc[~(df['BulkStatus'].isin(2,0,6,12), 'BulkStatus'] = 'Other'
     return df
 
 def impute_growth(df,impute_growth_flag):
